@@ -96,7 +96,7 @@ async def _write_stdin(stdin):
 async def _run_slapp(slapp_path: str, mode: str, restart_on_fail: bool = True):
     global slapp_loop
 
-    while restart_on_fail:
+    while True:
         proc = await asyncio.create_subprocess_shell(
             f'dotnet \"{slapp_path}\" \"%#%@%#%\" {mode}',
             stdin=asyncio.subprocess.PIPE,
@@ -115,6 +115,8 @@ async def _run_slapp(slapp_path: str, mode: str, restart_on_fail: bool = True):
             _write_stdin(proc.stdin)
         )
         logging.warning("_run_slapp returned!")
+        if not restart_on_fail:
+            break
 
 
 async def initialise_slapp(new_response_function: Callable[[str, dict], Any], mode: str = "--keepOpen"):
